<?php
//
// Copyright (c) 2008-2014 Nagios Enterprises, LLC.  All rights reserved.
//  
// $Id: utils.inc.php 2806 2014-07-11 15:57:43Z swilkerson $

require_once(dirname(__FILE__) . '/common.inc.php');

////////////////////////////////////////////////////////////////////////
// INIT FUNCTIONS
////////////////////////////////////////////////////////////////////////

function check_backend_prereqs()
{
    // Make ALL database connections
    $dbok = db_connect_all();

    // Handle bad db connection
    if ($dbok == false) {
        handle_backend_db_error();
    }
}

////////////////////////////////////////////////////////////////////////
// OUTPUT FUNCTIONS
////////////////////////////////////////////////////////////////////////

// Generate headers for API output
function output_backend_header()
{
    global $request;

    // What output are we using...
    $outputtype = grab_request_var("outputtype", "");

    // We usually output XML, except if debugging or if we want JSON, duh
    $debug = grab_request_var("debug", "");
    if ($debug == "text") {
        $outputtype = "text";
    } else if ($debug == "html") {
        $outputtype = "html";
    }

    // Always use text when debugging SQL
    if (isset($request["debugsql"])) {
        $outputtype = "text";
    }

    // Allow access to this XML via AJAX calls
    header("Access-Control-Allow-Origin: *");

    // Display headers based on output
    switch ($outputtype) {

        case "json":
            header("Content-type: application/json");
            break;

        case "text":
            header("Content-type: text/plain");
            break;

        case "html":
            header("Content-type: text/html");
            break;

        case "xml":
        default: // xml by default
            header("Content-type: text/xml");
            echo "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n";
            break;
    }
}

/**
 * @param        $code
 * @param string $msg
 */
function begin_backend_result($code, $msg = "")
{
    echo "<result>\n";
    echo "<code>$code</code>\n";
    echo "<message>$msg</message>\n";
}

function end_backend_result()
{
    echo "</result>\n";
}


////////////////////////////////////////////////////////////////////////
// DB FUNCTIONS
////////////////////////////////////////////////////////////////////////

/**
 * @param        $level
 * @param        $rs
 * @param        $fieldname
 * @param string $nodename
 * @param bool   $return
 *
 * @return string
 */
function xml_db_field($level, $rs, $fieldname, $nodename = "", $return = false)
{
    $temp = get_xml_db_field($level, $rs, $fieldname, $nodename);
    if ($return) {
        return $temp;
    } else {
        echo $temp;
    }
}

/**
 * @param $rs
 * @param $fieldname
 *
 * @return string|XML
 */
function db_field($rs, $fieldname)
{
    return get_xml_db_field_val($rs, $fieldname);
}

/**
 * @param      $level
 * @param      $nodename
 * @param      $nodevalue
 * @param bool $return
 *
 * @return string
 */
function xml_field($level, $nodename, $nodevalue, $return = false)
{
    $temp = get_xml_field($level, $nodename, $nodevalue);
    if ($return) {
        return $temp;
    } else {
        echo $temp;
    }
}
