<?php
// EXECUTIVE SUMMARY REPORT
//
// Copyright (c) 211 Nagios Enterprises, LLC.  All rights reserved.
//  
// $Id: execsummary.php 2933 2014-10-30 18:56:23Z jomann $

require_once(dirname(__FILE__) . '/../includes/common.inc.php');

// initialization stuff
pre_init();

// start session
init_session();

// grab GET or POST variables 
grab_request_vars();

// check prereqs
check_prereqs();

// check authentication
check_authentication(false);


route_request();

function route_request()
{

    /*
    if(is_admin()==false){
        echo "You are not authorized to view this report";
        exit();
        }
    */

    $mode = grab_request_var("mode", "");
    switch ($mode) {
        case "pdf":
            get_report_pdf();
            break;
        default:
            display_report();
            break;
    }
}


///////////////////////////////////////////////////////////////////
// REPORT GENERATION FUCNTIONS
///////////////////////////////////////////////////////////////////

// this function displays report in HTML
function display_report()
{
    global $request;

    // makes sure user has appropriate license level
    licensed_feature_check();

    // get values passed in GET/POST request
    $reportperiod = grab_request_var("reportperiod", "last24hours");
    $startdate = grab_request_var("startdate", "");
    $enddate = grab_request_var("enddate", "");
    //flag to hide select options (scheduled report and pdf)
    $hideoptions = grab_request_var('hideoptions', false);
    $manual_run = grab_request_var("manual_run", 0);

    // fix custom dates
    if ($reportperiod == "custom") {
        if ($enddate == "") {
            $enddate = strftime("%c", time());
        }
        if ($startdate == "") {
            $startdate = strftime("%c", time() - (60 * 60 * 24));
            $enddate = strftime("%c", time());
        }
    }

    $host = grab_request_var("host", "");
    $hostgroup = grab_request_var("hostgroup", "");
    $servicegroup = grab_request_var("servicegroup", "");


    // start/end times must be in unix timestamp format
    // if they weren't specified, default to last 24 hours
    //$endtime=grab_request_var("endtime",time());
    //$starttime=grab_request_var("starttime",$endtime-(24*60*60));

    // determine start/end times based on period
    get_times_from_report_timeperiod($reportperiod, $starttime, $endtime, $startdate, $enddate);


    // start the HTML page
    do_page_start(array("page_title" => gettext("Executive Summary")), true);

// Options can be suppressed for rendered reports
    if ($hideoptions) {

        // default logo stuff
        $logo = "nagiosxi-logo-small.png";
        $logo_alt = get_product_name();

        // use custom logo if it exists
        $logosettings_raw = get_option("custom_logo_options");
        if ($logosettings_raw == "") {
            $logosettings = array();
        } else {
            $logosettings = unserialize($logosettings_raw);
        }

        $custom_logo_enabled = grab_array_var($logosettings, "enabled");
        if ($custom_logo_enabled == 1) {
            $logo = grab_array_var($logosettings, "logo", $logo);
            $logo_alt = grab_array_var($logosettings, "logo_alt", $logo_alt);
        }
        ?>


        <div style="padding-bottom: 10px;">
            <div style="float: left; margin-right: 30px;">
                <img src="<?php echo get_base_url(); ?>images/<?php echo $logo; ?>" border="0"
                     alt="<?php echo $logo_alt; ?>" title="<?php echo $logo_alt; ?>">
            </div>
            <div style="float: left; height: 44px;">
                <div
                    style="font-weight: bold; font-size: 22px; padding-bottom: 4px;"><?php echo gettext("Executive Summary"); ?></div>
                <div><?php echo gettext("From"); ?>:
                    <strong><?php echo get_datetime_string($starttime, DT_SHORT_DATE_TIME, DF_AUTO, "null"); ?></strong> <?php echo gettext("To"); ?>
                    : <strong><?php echo get_datetime_string($endtime, DT_SHORT_DATE_TIME, DF_AUTO, "null"); ?></strong>
                </div>
            </div>
            <div style="clear:both;"></div>
        </div>

    <?php
    } else {
        ?>
        <h1><?php echo gettext("Executive Summary"); ?></h1>

        <form method="get" action="<?php echo htmlentities($_SERVER["REQUEST_URI"]); ?>">

            <div class="reportexportlinks">
                <?php echo get_add_myreport_html("Executive Summary", htmlentities($_SERVER["REQUEST_URI"]), array()); ?>
                <?php
                $url = "?1";
                foreach ($request as $var => $val)
                    $url .= "&" . urlencode($var) . "=" . urlencode($val);
                ?>
                <!--//-->
                <a href="<?php echo $url; ?>&mode=pdf" alt="<?php echo gettext("Download As PDF"); ?>"
                   title="<?php echo gettext("Download As PDF"); ?>"><img
                        src="<?php echo theme_image("pdf.png"); ?>"></a>

            </div>


            <?php
            $auto_start_date = get_datetime_string(strtotime('yesterday'), DT_SHORT_DATE);
            $auto_end_date = get_datetime_string(strtotime('Today'), DT_SHORT_DATE);
            ?>

            <script type="text/javascript">
                $(document).ready(function () {
                    $('#startdateBox').click(function () {
                        $('#reportperiodDropdown').val('custom');
                        if ($('#startdateBox').val() == '' && $('#enddateBox').val() == '') {
                            $('#startdateBox').val('<?php echo $auto_start_date;?>');
                            $('#enddateBox').val('<?php echo $auto_end_date;?>');
                        }
                    });
                    $('#enddateBox').click(function () {
                        $('#reportperiodDropdown').val('custom');
                        if ($('#startdateBox').val() == '' && $('#enddateBox').val() == '') {
                            $('#startdateBox').val('<?php echo $auto_start_date;?>');
                            $('#enddateBox').val('<?php echo $auto_end_date;?>');
                        }
                    });

                    showhidedates();

                    $('#reportperiodDropdown').change(function () {
                        showhidedates();
                    });

                    function showhidedates() {
                        if ($('#reportperiodDropdown').val() == 'custom')
                            $('#customdates').show();
                        else
                            $('#customdates').hide();
                    }

                });
            </script>

            <div class="reporttimepicker">
                <div style="float: left; padding-right: 10px;">
                    <?php echo gettext("Period"); ?>&nbsp;
                    <select id='reportperiodDropdown' name="reportperiod">
                        <?php
                        $tp = get_report_timeperiod_options();
                        foreach ($tp as $shortname => $longname) {
                            echo "<option value='" . $shortname . "' " . is_selected($shortname, $reportperiod) . ">" . $longname . "</option>";
                        }
                        ?>
                    </select>
                </div>

                <div id="customdates" class="hide" style="float: left;">
                    &nbsp;<?php echo gettext("From"); ?>&nbsp;
                    <input class="textfield" type="text" id='startdateBox' name="startdate"
                           value="<?php echo $startdate; ?>" size="16"/>

                    <div class="reportstartdatepicker"><img src="<?php echo theme_image("calendar_small.png"); ?>">
                    </div>
                    <div id="startdatepickercontainer"></div>
                    &nbsp;<?php echo gettext("To"); ?>&nbsp;
                    <input class="textfield" type="text" id='enddateBox' name="enddate" value="<?php echo $enddate; ?>"
                           size="16"/>

                    <div class="reportenddatepicker"><img src="<?php echo theme_image("calendar_small.png"); ?>"></div>
                    <div id="enddatepickercontainer"></div>
                    &nbsp;
                </div>
            </div>

            <div class="reportoptionpicker" style="clear: left;">
                <!-- options go here... -->
                <?php echo gettext("Limit To"); ?>&nbsp;

                <select name="host" id="hostList" style="width: 150px;">
                    <option value=""><?php echo gettext("Host"); ?>:</option>
                    <?php
                    $args = array('brevity' => 1, 'orderby' => 'host_name:a');
                    $oxml = get_xml_host_objects($args);
                    if ($oxml) {
                        foreach ($oxml->host as $hostobject) {
                            $name = strval($hostobject->host_name);
                            echo "<option value='" . $name . "' " . is_selected($host, $name) . ">$name</option>\n";
                        }
                    }
                    ?>
                </select>

                <select name="hostgroup" id="hostgroupList" style="width: 150px;">
                    <option value=""><?php echo gettext("Hostgroup"); ?>:</option>
                    <?php
                    $args = array('orderby' => 'hostgroup_name:a');
                    $oxml = get_xml_hostgroup_objects($args);
                    if ($oxml) {
                        foreach ($oxml->hostgroup as $hg) {
                            $name = strval($hg->hostgroup_name);
                            echo "<option value='" . $name . "' " . is_selected($hostgroup, $name) . ">$name</option>\n";
                        }
                    }
                    ?>
                </select>
                <select name="servicegroup" id="servicegroupList" style="width: 150px;">
                    <option value=""><?php echo gettext("Servicegroup"); ?>:</option>
                    <?php
                    $args = array('orderby' => 'servicegroup_name:a');
                    $oxml = get_xml_servicegroup_objects($args);
                    if ($oxml) {
                        foreach ($oxml->servicegroup as $sg) {
                            $name = strval($sg->servicegroup_name);
                            echo "<option value='" . $name . "' " . is_selected($servicegroup, $name) . ">$name</option>\n";
                        }
                    }
                    ?>
                </select>

                <input type='submit' class='reporttimesubmitbutton' name='reporttimesubmitbutton'
                       value='<?php echo gettext("Update"); ?>'>

                <script type="text/javascript">
                    $(document).ready(function () {

                        $('#hostList').change(function () {
                            $('#hostgroupList').val('');
                            $('#servicegroupList').val('');
                        });
                        $('#servicegroupList').change(function () {
                            $('#hostList').val('');
                            $('#hostgroupList').val('');
                        });
                        $('#hostgroupList').change(function () {
                            $('#servicegroupList').val('');
                            $('#hostList').val('');
                        });
                    });
                </script>

            </div>

            <!-- Set a variable to let us know it's okay to run this -->
            <input type="hidden" name="manual_run" value="1">

        </form>

        <?php
        // Die right here if we don't want to auto-load the page
        $disable_report_auto_run = get_option("disable_report_auto_run", 0);
        if ($disable_report_auto_run == 1 && $manual_run == 0) {
            die();
        }
        ?>

        <div>
            <?php echo gettext("Report Covers"); ?> <?php echo gettext("From"); ?>:
            <b><?php echo get_datetime_string($starttime, DT_SHORT_DATE_TIME, DF_AUTO, "null"); ?></b>
            <?php echo gettext("To"); ?>:
            <b><?php echo get_datetime_string($endtime, DT_SHORT_DATE_TIME, DF_AUTO, "null"); ?></b>
        </div>

    <?php
    } //end if $hide_options
    ?>

    <script type='text/javascript'>
        /* AJAX load the different report from around the site */
        $(document).ready(function () {
            <?php
                    $arg = '';
                    foreach($request as $var => $val)
                        $arg.="&".urlencode($var)."=".urlencode($val);
            ?>
            $('#inner_availability').load('availability.php?hideoptions=1&showonlygraphs=1<?php echo $arg;?>');
            $('#inner_top_alert_producers').load('topalertproducers.php?records=10<?php echo $arg;?> #top_alert_producers');
            //load dashlet content into div
            $('#inner_latest_alerts').each(function () {
                var optsarr = {
                    "func": "get_latestalerts_dashlet_html",
                    "args": {
                        "type": "",
                        "host": "<?php echo $host;?>",
                        "hostgroup": "<?php echo $hostgroup;?>",
                        "servicegroup": "<?php echo $servicegroup;?>",
                        "maxitems": "10"
                    }
                }
                var opts = array2json(optsarr);
                get_ajax_data_innerHTML("getxicoreajax", opts, true, this);
            });

        });
    </script>

    <!-- remove inline styles -->
    <div id='allreports' style='margin:10px auto;'>

        <div class='availability' style='float:left; margin-right: 20px;'>
            <h3><?php echo gettext("Availability"); ?></h3>

            <div id='inner_availability'>
                <div class="childcontentthrobber" id='availabilitythrobber'>
                    <img src="/nagiosxi/images/throbber1.gif"/>
                </div>
            </div>
        </div>
        <div class='top_alert_producers' style='float:left; width: 450px;'>
            <h3><?php echo gettext("Top Alert Producers"); ?></h3>

            <div id='inner_top_alert_producers'>
                <div class="childcontentthrobber" id='topalertsthrobber'>
                    <img src="/nagiosxi/images/throbber1.gif"/>
                </div>
            </div>
        </div>

        <br clear="all"/>
        <!-- remove inline styles -->
        <div class='alert_histogram' style="margin-bottom: 20px;">
            <h3><?php echo gettext("Alert Histogram"); ?></h3>

            <div id='inner_alert_histogram'>
                <?php
                $url = 'histogram.php?mode=image';
                foreach ($request as $var => $val) {
                    $url .= "&" . urlencode($var) . "=" . urlencode($val);
                }
                ?>
                <br/>
                <script type="text/javascript">
                    $(document).ready(function () {
                        $('#hostList').change(function () {
                            $('#hostgroupList').val('');
                            $('#servicegroupList').val('');
                        });
                        $('#servicegroupList').change(function () {
                            $('#hostList').val('');
                            $('#hostgroupList').val('');
                        });
                        $('#hostgroupList').change(function () {
                            $('#servicegroupList').val('');
                            $('#hostList').val('');
                        });

                        <?php if($hideoptions): ?>
                        var tracking = false;
                        <?php else: ?>
                        var tracking = true;
                        <?php endif; ?>

                        var api_url = '<?php echo $url; ?>';
                        $.getJSON(api_url,
                            function (data) {
                                var chart;
                                var options = {
                                    'plotOptions': {'series': {'enableMouseTracking': tracking, 'animation': false}},
                                    'chart': {
                                        'renderTo': 'alert_histogram_image',
                                        'width': 600,
                                        'height': 225
                                    },
                                    'credits': {'enabled': false},
                                    'title': {'text': data.graph_title},
                                    'xAxis': {
                                        'categories': data.categories,
                                        'title': {'text': data.x_label},
                                        'labels': {
                                            'rotation': -45,
                                            'align': 'right'
                                        }
                                    },
                                    'yAxis': {
                                        'title': {'text': data.y_label},
                                        'min': 0
                                    },
                                    'series': [
                                        {
                                            'data': data.data,
                                            'name': data.name
                                        }
                                    ]
                                }
                                chart = new Highcharts.Chart(options);
                            });
                    });
                </script>
                <div id='alert_histogram_image'></div>
            </div>
        </div>

        <!-- style="float: left; margin: 10px; padding: 10px; border: 1px solid gray;" -->


        <div class='most_recent_alerts'>
            <div id='inner_latest_alerts'>
                <div class="childcontentthrobber" id='latestalertsthrobber'>
                    <img src="/nagiosxi/images/throbber1.gif"/>
                </div>
            </div>
        </div>

    </div> <!-- end allreports div -->
    <?php

    // closes the HTML page
    do_page_end(true);
}

function get_report_pdf()
{
    global $cfg;

    //get user name
    $username = $_SESSION["username"];
    // get backend ticket
    $backend_ticket = get_user_attr(0, "backend_ticket");

    // Assemble actual URL that will be gotten
    $prefix = ($cfg['use_https'] == true) ? 'https' : 'http';
    $uri = str_replace("mode=pdf", "hideoptions=1", $_SERVER["REQUEST_URI"]);
    $fullurl = "{$prefix}://127.0.0.1{$uri}";
    //echo "FULLURL: $fullurl\n";

    $urlparts = parse_url($fullurl);

    $newurl = "";
    $newurl .= get_internal_url() . "/reports/execsummary.php";
    $newurl .= "?";
    if (isset($urlparts['query']))
        $newurl .= $urlparts['query'];

    $newurl .= "&username=" . $username;
    $newurl .= "&ticket=" . $backend_ticket;

    //echo "NEWURL: $newurl\n";

    // Add language to url
    $language = $_SESSION['language'];
    $newurl .= "&locale=" . $language;

    // Do page rendering

    $aurl = $newurl;

    $afile = "page.pdf";
    $fname = get_tmp_dir() . "/scheduledreport-" . $username . "-" . time() . "-" . $afile;

    $cmdft = '--footer-spacing 3 --margin-bottom 15mm --footer-font-size 9 --footer-right "Page [page] of [toPage]" --footer-left "' . get_datetime_string(time(), DT_SHORT_DATE_TIME, DF_AUTO, "null") . '"';

    $cmd = "/usr/bin/wkhtmltopdf --no-outline {$cmdft} '{$aurl}' '{$fname}' 2>&1";
    @exec($cmd);

    //echo "CMD: $cmd\n";
    //exit();

    if (!file_exists($fname)) {
        echo "\n\n************\nERROR: Failed to render URL '" . $aurl . "' as '" . $fname . "'\n************\n\n";
    } else {
        // We'll be outputting a PDF
        header('Content-type: application/pdf');
        header('Content-Disposition: inline; filename="execsummary.pdf"');

        // The PDF source is in original.pdf
        readfile($fname);
        unlink($fname);
    }
}

?>